<?php

/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\ForIbn4203\Controller;

use Eccube\Controller\AbstractController;
use Plugin\ForIbn4203\Entity\Ibn4203Carousel;
use Plugin\ForIbn4203\Form\Type\Ibn4203CarouselType;
use Plugin\ForIbn4203\Repository\Ibn4203CarouselRepository;
use Eccube\Util\CacheUtil;
use Knp\Component\Pager\PaginatorInterface;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Form\Form;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;


/**
 * Class Ibn4203CarouselController.
 */
class Ibn4203CarouselController extends AbstractController
{
    /**
     * @var Ibn4203CarouselRepository
     */
    private $ibn4203CarouselRepository;

    /**
     * Ibn4203CarouselController constructor.
     *
     * @param Ibn4203CarouselRepository $ibn4203CarouselRepository
     */
    public function __construct(Ibn4203CarouselRepository $ibn4203CarouselRepository)
    {
        $this->ibn4203CarouselRepository = $ibn4203CarouselRepository;
    }

    /**
     * 一覧を表示する。
     *
     * @param Request     $request
     *
     * @return array
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel", name="admin_content_ibn4203_carousel")
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel/page/{page_no}", requirements={"page_no" = "\d+"}, name="admin_content_ibn4203_carousel_page")
     * @Template("@ForIbn4203/admin/ibn4203_carousel.twig")
     */
    public function index(Request $request, PaginatorInterface $paginator, $page_no = 1)
    {
        $qb = $this->ibn4203CarouselRepository
            ->findBy(
                [],
                ['sort_no' => 'DESC']
            );

        $pagination = $paginator->paginate(
            $qb,
            $page_no,
            $this->eccubeConfig->get('eccube_default_page_count')
        );

        return [
            'pagination' => $pagination,
        ];
    }

    /**
     * 登録・編集する。
     *
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel/new", name="admin_content_ibn4203_carousel_new")
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel/{id}/edit", requirements={"id" = "\d+"}, name="admin_content_ibn4203_carousel_edit")
     * @Template("@ForIbn4203/admin/ibn4203_carousel_edit.twig")
     */
    public function edit(Request $request, Ibn4203Carousel $Ibn4203Carousel = null, CacheUtil $cacheUtil)
    {
        if (is_null($Ibn4203Carousel)) {
            $Ibn4203Carousel = $this->ibn4203CarouselRepository->findOneBy([], ['sort_no' => 'DESC']);
            $sortNo = 1;
            if ($Ibn4203Carousel) {
                $sortNo = $Ibn4203Carousel->getSortNo() + 1;
            }

            $Ibn4203Carousel = new \Plugin\ForIbn4203\Entity\Ibn4203Carousel();
            $Ibn4203Carousel
                ->setSortNo($sortNo)
                ->setFixed(true)
                ->setVisible(true);
        }

        $builder = $this->formFactory
            ->createBuilder(Ibn4203CarouselType::class, $Ibn4203Carousel);

        $form = $builder->getForm();
		
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {

            $this->ibn4203CarouselRepository->save($Ibn4203Carousel);

            $this->addSuccess('admin.common.save_complete', 'admin');

            // キャッシュの削除
            $cacheUtil->clearDoctrineCache();

            return $this->redirectToRoute('admin_content_ibn4203_carousel_edit', ['id' => $Ibn4203Carousel->getId()]);
        }

        return [
            'form' => $form->createView(),
            'Ibn4203Carousel' => $Ibn4203Carousel,
        ];
    }

    /**
     * 指定したデータを削除する。
     *
     * @param Request     $request
     * @param Ibn4203Carousel $Ibn4203Carousel
     *
     * @throws \Exception
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel/{id}/delete", requirements={"id" = "\d+"}, name="admin_content_ibn4203_carousel_delete", methods={"DELETE"})
     */
    public function delete(Request $request, Ibn4203Carousel $Ibn4203Carousel, CacheUtil $cacheUtil)
    {
        $this->isTokenValid();

        log_info('新入荷商品特集削除開始', [$Ibn4203Carousel->getId()]);

        try {
            $this->ibn4203CarouselRepository->delete($Ibn4203Carousel);

            $this->addSuccess('admin.common.delete_complete', 'admin');

            log_info('新入荷商品特集削除完了', [$Ibn4203Carousel->getId()]);

            // キャッシュの削除
            $cacheUtil->clearDoctrineCache();

        } catch (\Exception $e) {
            $message = trans('admin.common.delete_error_foreign_key', ['%name%' => $Ibn4203Carousel->getTopImage()]);
            $this->addError($message, 'admin');

            log_error('新入荷商品特集削除エラー', [$Ibn4203Carousel->getId(), $e]);
        }

        $sortNo = 1;
        $Ibn4203Carousels = $this->ibn4203CarouselRepository
            ->findBy([], ['sort_no' => 'ASC']);

        foreach ($Ibn4203Carousels as $Ibn4203Carousel) {
                $Ibn4203Carousel->setSortNo($sortNo);
                $sortNo++;
        }
        $this->entityManager->flush();

        return $this->redirectToRoute('admin_content_ibn4203_carousel');
    }

    /**
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel/{id}/visibility", requirements={"id" = "\d+"}, name="admin_content_ibn4203_carousel_visibility", methods={"PUT"})
     */
    public function visibility(Request $request, Ibn4203Carousel $Ibn4203Carousel)
    {
        $this->isTokenValid();

        // 表示・非表示を切り替える
        if ($Ibn4203Carousel->isVisible()) {
            $message = trans('admin.common.to_hide_complete', ['%name%' => $Ibn4203Carousel->getId()]);
            $Ibn4203Carousel->setVisible(false);
        } else {
            $message = trans('admin.common.to_show_complete', ['%name%' => $Ibn4203Carousel->getId()]);
            $Ibn4203Carousel->setVisible(true);
        }
        $this->entityManager->persist($Ibn4203Carousel);

        $this->entityManager->flush();

        $this->addSuccess($message, 'admin');

        return $this->redirectToRoute('admin_content_ibn4203_carousel');
    }

    /**
     * @Route("/%eccube_admin_route%/content/ibn4203_carousel/sort_no/move", name="admin_content_ibn4203_carousel_sort_no_move", methods={"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function moveSortNo(Request $request)
    {
        if (!$request->isXmlHttpRequest()) {
            throw new BadRequestHttpException();
        }

        if ($this->isTokenValid()) {
            $sortNos = $request->request->all();
            foreach ($sortNos as $ibn4203CarouselId => $sortNo) {
                $Ibn4203Carousel = $this->ibn4203CarouselRepository->find($ibn4203CarouselId);
                $Ibn4203Carousel->setSortNo($sortNo);
                $this->entityManager->persist($Ibn4203Carousel);
            }
            $this->entityManager->flush();
        }

        return $this->json('OK', 200);
    }
}
