<?php

/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\ForIbn4203\Controller;

use Eccube\Controller\AbstractController;
use Plugin\ForIbn4203\Entity\ListpageImgcont;
use Eccube\Event\EccubeEvents;
use Eccube\Event\EventArgs;
use Plugin\ForIbn4203\Form\Type\ListpageImgcontType;
use Plugin\ForIbn4203\Repository\ListpageImgcontRepository;
use Eccube\Util\CacheUtil;
use Knp\Component\Pager\PaginatorInterface;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Routing\Annotation\Route;

//▼画像アップロード
use Symfony\Component\Filesystem\Filesystem;
use Symfony\Component\HttpKernel\Exception\UnsupportedMediaTypeHttpException;
use Symfony\Component\HttpFoundation\Response;

class ListpageImgcontController extends AbstractController
{
    /**
     * @var ListpageImgcontRepository
     */
    protected $listpageImgcontRepository;

    /**
     * ListpageImgcontController constructor.
     *
     * @param ListpageImgcontRepository $listpageImgcontRepository
     */
    public function __construct(ListpageImgcontRepository $listpageImgcontRepository)
    {
        $this->listpageImgcontRepository = $listpageImgcontRepository;
    }

    /**
     * 一覧を表示する。
     *
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont", name="plugin_listpage_imgcont")
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/page/{page_no}", requirements={"page_no" = "\d+"}, name="plugin_listpage_imgcont_page")
     * @Template("@ForIbn4203/admin/listpage_imgcont.twig")
     *
     * @param Request $request
     * @param int $page_no
     * @param Paginator $paginator
     *
     * @return array
     */
    public function index(Request $request, PaginatorInterface $paginator, $page_no = 1)
    {
        $qb = $this->listpageImgcontRepository
            ->findBy(
                [],
                ['sort_no' => 'DESC']
            );

        $pagination = $paginator->paginate(
            $qb,
            $page_no,
            $this->eccubeConfig->get('eccube_default_page_count')
        );

        return [
            'pagination' => $pagination,
        ];
    }

    /**
     * 登録・編集する。
     *
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/new", name="plugin_listpage_imgcont_new")
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/{id}/edit", requirements={"id" = "\d+"}, name="plugin_listpage_imgcont_edit")
     * @Template("@ForIbn4203/admin/listpage_imgcont_edit.twig")
     *
     * @param Request $request
     * @param null $id
     *
     * @return array|\Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function edit(Request $request, ListpageImgcont $ListpageImgcont = null, CacheUtil $cacheUtil)
    {
        if (is_null($ListpageImgcont)) {
            $ListpageImgcont = $this->listpageImgcontRepository->findOneBy([], ['sort_no' => 'DESC']);
            $sortNo = 1;
            if ($ListpageImgcont) {
                $sortNo = $ListpageImgcont->getSortNo() + 1;
            }

            $ListpageImgcont = new \Plugin\ForIbn4203\Entity\ListpageImgcont();
            $ListpageImgcont
                ->setSortNo($sortNo)
                ->setFixed(true)
                ->setVisible(true);
        }

        $builder = $this->formFactory
            ->createBuilder(ListpageImgcontType::class, $ListpageImgcont);

        $form = $builder->getForm();
		
        //▼画像アップロード
		// 既に画像保存されてる場合は取得する
        $oldListpageImgcontImage = $ListpageImgcont->getListpageImgcontImage();
        $form->setData($ListpageImgcont);
		//▲

        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {

			//▼画像アップロード
            $ListpageImgcont = $form->getData();
            // ファイルアップロード
            $file = $form['listpage_imgcont_image']->getData();
            $fs = new Filesystem();
            if ($file && $fs->exists($this->getParameter('eccube_temp_image_dir').'/'.$file)) {
                $fs->rename(
                    $this->getParameter('eccube_temp_image_dir').'/'.$file,
                    $this->getParameter('eccube_save_image_dir').'/'.$file
                );
            }
			//▲
			
            $this->listpageImgcontRepository->save($ListpageImgcont);

            $this->addSuccess('admin.common.save_complete', 'admin');

            // キャッシュの削除
            $cacheUtil->clearDoctrineCache();

            return $this->redirectToRoute('plugin_listpage_imgcont_edit', ['id' => $ListpageImgcont->getId()]);
        }

        return [
            'form' => $form->createView(),
            'ListpageImgcont' => $ListpageImgcont,
            'oldListpageImgcontImage' => $oldListpageImgcontImage, //▼画像アップロード
        ];
    }

    //▼画像アップロード
	/**
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/image/process", name="admin_listpage_imgcont_image_process")
     */
    public function imageProcess(Request $request)
    {
        if (!$request->isXmlHttpRequest()) {
            throw new BadRequestHttpException();
        }

        $images = $request->files->get('admin_listpage_imgcont'); //ListpageImgcontType.phpの最下部、return 'admin_listpage_imgcont'
        $allowExtensions = ['gif', 'jpg', 'jpeg', 'png'];
        $filename = null;
        if (isset($images['listpage_imgcont_image_file'])) {
            $image = $images['listpage_imgcont_image_file'];

            //ファイルフォーマット検証
            $mimeType = $image->getMimeType();
            if (0 !== strpos($mimeType, 'image')) {
                throw new UnsupportedMediaTypeHttpException();
            }

            // 拡張子
            $extension = $image->getClientOriginalExtension();
            if (!in_array($extension, $allowExtensions)) {
                throw new UnsupportedMediaTypeHttpException();
            }

            $filename = date('mdHis').uniqid('_').'.'.$extension;
            $image->move($this->getParameter('eccube_temp_image_dir'), $filename);
        }

        return new Response($filename);
    }

	// ▼画像アップロード
    /**
     * アップロード画像を取得する際にコールされるメソッド.
     *
     * @see https://pqina.nl/filepond/docs/api/server/#load
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/image/load", name="admin_listpage_imgcont_image_load")
     */
    public function imageLoad(Request $request)
    {
        if (!$request->isXmlHttpRequest()) {
            throw new BadRequestHttpException();
        }

        $dirs = [
            $this->eccubeConfig['eccube_save_image_dir'],
            $this->eccubeConfig['eccube_temp_image_dir'],
        ];

        foreach ($dirs as $dir) {
            $image = \realpath($dir.'/'.$request->query->get('source'));
            $dir = \realpath($dir);

            if (\is_file($image) && \str_starts_with($image, $dir)) {
                $file = new \SplFileObject($image);

                return $this->file($file, $file->getBasename());
            }
        }

        throw new NotFoundHttpException();
    }

	// ▼画像アップロード
    /**
     * アップロード画像をすぐ削除する際にコールされるメソッド.
     *
     * @see https://pqina.nl/filepond/docs/api/server/#revert
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/image/revert", name="admin_listpage_imgcont_image_revert")
     */
    public function imageRevert(Request $request)
    {
        if (!$request->isXmlHttpRequest() && $this->isTokenValid()) {
            throw new BadRequestHttpException();
        }

        $tempFile = $this->eccubeConfig['eccube_temp_image_dir'].'/'.$request->getContent();
        if (is_file($tempFile) && stripos(realpath($tempFile), $this->eccubeConfig['eccube_temp_image_dir']) === 0) {
            $fs = new Filesystem();
            $fs->remove($tempFile);

            return new Response(null, Response::HTTP_NO_CONTENT);
        }

        throw new NotFoundHttpException();
    }

    /**
     * 指定したデータを削除する。
     *
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/{id}/delete", requirements={"id" = "\d+"}, name="plugin_listpage_imgcont_delete", methods={"DELETE"})
     *
     * @param Request $request
     * @param ListpageImgcont $ListpageImgcont
     *
     * @return \Symfony\Component\HttpFoundation\RedirectResponse
     */
    public function delete(Request $request, ListpageImgcont $ListpageImgcont, CacheUtil $cacheUtil)
    {
        $this->isTokenValid();

        log_info('カテゴリバナー画像削除開始', [$ListpageImgcont->getId()]);

        try {
            $this->listpageImgcontRepository->delete($ListpageImgcont);

            $this->addSuccess('admin.common.delete_complete', 'admin');

            log_info('カテゴリバナー画像削除完了', [$ListpageImgcont->getId()]);

            // キャッシュの削除
            $cacheUtil->clearDoctrineCache();

        } catch (\Exception $e) {
            $message = trans('admin.common.delete_error_foreign_key', ['%name%' => $ListpageImgcont->getTopImage()]);
            $this->addError($message, 'admin');

            log_error('カテゴリバナー画像削除エラー', [$ListpageImgcont->getId(), $e]);
        }

        $sortNo = 1;
        $ListpageImgconts = $this->listpageImgcontRepository
            ->findBy([], ['sort_no' => 'ASC']);

        foreach ($ListpageImgconts as $ListpageImgcont) {
                $ListpageImgcont->setSortNo($sortNo);
                $sortNo++;
        }
        $this->entityManager->flush();

        return $this->redirectToRoute('plugin_listpage_imgcont');
    }

    /**
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/{id}/visibility", requirements={"id" = "\d+"}, name="plugin_listpage_imgcont_visibility", methods={"PUT"})
     */
    public function visibility(Request $request, ListpageImgcont $ListpageImgcont)
    {
        $this->isTokenValid();

        // 表示・非表示を切り替える
        if ($ListpageImgcont->isVisible()) {
            $message = trans('admin.common.to_hide_complete', ['%name%' => $ListpageImgcont->getId()]);
            $ListpageImgcont->setVisible(false);
        } else {
            $message = trans('admin.common.to_show_complete', ['%name%' => $ListpageImgcont->getId()]);
            $ListpageImgcont->setVisible(true);
        }
        $this->entityManager->persist($ListpageImgcont);

        $this->entityManager->flush();

        $this->addSuccess($message, 'admin');

        return $this->redirectToRoute('plugin_listpage_imgcont');
    }

    /**
     * @Route("/%eccube_admin_route%/plugin/listpage_imgcont/sort_no/move", name="plugin_listpage_imgcont_sort_no_move", methods={"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function moveSortNo(Request $request)
    {
        if (!$request->isXmlHttpRequest()) {
            throw new BadRequestHttpException();
        }

        if ($this->isTokenValid()) {
            $sortNos = $request->request->all();
            foreach ($sortNos as $listpageImgcontId => $sortNo) {
                $ListpageImgcont = $this->listpageImgcontRepository->find($listpageImgcontId);
                $ListpageImgcont->setSortNo($sortNo);
                $this->entityManager->persist($ListpageImgcont);
            }
            $this->entityManager->flush();
        }

        return $this->json('OK', 200);
    }

}
