<?php

/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\ForIbn4203\Entity;

use Doctrine\ORM\Mapping as ORM;
use Eccube\Entity\AbstractEntity;

/**
 * Ibn4203Carousel
 *
 * @ORM\Table(name="plg_ibn4203_carousel")
 * @ORM\InheritanceType("SINGLE_TABLE")
 * @ORM\DiscriminatorColumn(name="discriminator_type", type="string", length=255)
 * @ORM\HasLifecycleCallbacks()
 * @ORM\Entity(repositoryClass="Plugin\ForIbn4203\Repository\Ibn4203CarouselRepository")
 */
class Ibn4203Carousel extends AbstractEntity
{
	/**
	 * @var int
	 *
	 * @ORM\Column(name="id", type="integer", options={"unsigned":true})
	 * @ORM\Id
	 * @ORM\GeneratedValue(strategy="IDENTITY")
	 */
	private $id;

	/**
	 * @var string|null
	 *
	 * @ORM\Column(name="product_id", type="text", nullable=false)
	 */
	private $product_id;

	/**
	 * @var int|null
	 *
	 * @ORM\Column(name="sort_no", type="smallint", nullable=true, options={"unsigned":true})
	 */
	private $sort_no;

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="fixed", type="boolean", options={"default":true})
	 */
	private $fixed = true;

	/**
	 * @var \DateTime
	 *
	 * @ORM\Column(name="create_date", type="datetimetz")
	 */
	private $create_date;

	/**
	 * @var \DateTime
	 *
	 * @ORM\Column(name="update_date", type="datetimetz")
	 */
	private $update_date;

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="visible", type="boolean", options={"default":true})
	 */
	private $visible;

	/**
	 * @var \Eccube\Entity\Member
	 *
	 * @ORM\ManyToOne(targetEntity="Eccube\Entity\Member")
	 * @ORM\JoinColumns({
	 *   @ORM\JoinColumn(name="creator_id", referencedColumnName="id")
	 * })
	 */
	private $Creator;

	/**
	 * Get id.
	 *
	 * @return int
	 */
	public function getId()
	{
	    return $this->id;
	}

	/**
	 * Set productId.
	 *
	 * @param boolean $productId
	 *
	 * @return Ibn4203Carousel
	 */
	public function setProductId($productId)
	{
	    $this->product_id = $productId;

	    return $this;
	}

	/**
	 * Get productId.
	 *
	 * @return boolean
	 */
	public function getProductId()
	{
	    return $this->product_id;
	}

	/**
	 * Set sortNo.
	 *
	 * @param int|null $sortNo
	 *
	 * @return Ibn4203Carousel
	 */
	public function setSortNo($sortNo = null)
	{
	    $this->sort_no = $sortNo;

	    return $this;
	}

	/**
	 * Get sortNo.
	 *
	 * @return int|null
	 */
	public function getSortNo()
	{
	    return $this->sort_no;
	}

	/**
	 * Set fixed.
	 *
	 * @param boolean $fixed
	 *
	 * @return Ibn4203Carousel
	 */
	public function setFixed($fixed)
	{
	    $this->fixed = $fixed;

	    return $this;
	}

	/**
	 * Get fixed.
	 *
	 * @return boolean
	 */
	public function isFixed()
	{
	    return $this->fixed;
	}

	/**
	 * Set createDate.
	 *
	 * @param \DateTime $createDate
	 *
	 * @return Ibn4203Carousel
	 */
	public function setCreateDate($createDate)
	{
	    $this->create_date = $createDate;

	    return $this;
	}

	/**
	 * Get createDate.
	 *
	 * @return \DateTime
	 */
	public function getCreateDate()
	{
	    return $this->create_date;
	}

	/**
	 * Set updateDate.
	 *
	 * @param \DateTime $updateDate
	 *
	 * @return Ibn4203Carousel
	 */
	public function setUpdateDate($updateDate)
	{
	    $this->update_date = $updateDate;

	    return $this;
	}

	/**
	 * Get updateDate.
	 *
	 * @return \DateTime
	 */
	public function getUpdateDate()
	{
	    return $this->update_date;
	}

	/**
	 * @return integer
	 */
	public function isVisible()
	{
	    return $this->visible;
	}

	/**
	 * @param boolean $visible
	 *
	 * @return Ibn4203Carousel
	 */
	public function setVisible($visible)
	{
	    $this->visible = $visible;

	    return $this;
	}

	/**
	 * Set creator.
	 *
	 * @param \Eccube\Entity\Member|null $creator
	 *
	 * @return Ibn4203Carousel
	 */
	public function setCreator(\Eccube\Entity\Member $creator = null)
	{
	    $this->Creator = $creator;

	    return $this;
	}

	/**
	 * Get creator.
	 *
	 * @return \Eccube\Entity\Member|null
	 */
	public function getCreator()
	{
	    return $this->Creator;
	}
}
