<?php

/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\ForIbn4203\Entity;

use Doctrine\ORM\Mapping as ORM;
use Eccube\Entity\AbstractEntity;

if (!class_exists('\Plugin\ForIbn4203\Entity\Ibn4203Topic')) {
    /**
     * Ibn4203Topic
     *
     * @ORM\Table(name="plg_ibn4203_topic")
     * @ORM\InheritanceType("SINGLE_TABLE")
     * @ORM\DiscriminatorColumn(name="discriminator_type", type="string", length=255)
     * @ORM\HasLifecycleCallbacks()
     * @ORM\Entity(repositoryClass="Plugin\ForIbn4203\Repository\Ibn4203TopicRepository")
     */
    class Ibn4203Topic extends AbstractEntity
    {
        /**
         * @var int
         *
         * @ORM\Column(name="id", type="integer", options={"unsigned":true})
         * @ORM\Id
         * @ORM\GeneratedValue(strategy="IDENTITY")
         */
        private $id;

        /**
         * @var string|null
         *
         * @ORM\Column(name="url", type="string", length=4000, nullable=true)
         */
        private $url;

        /**
         * @var boolean
         *
         * @ORM\Column(name="link_method", type="boolean", options={"default":false})
         */
        private $link_method = false;

        /**
         * @var string|null
         *
         * @ORM\Column(name="topic_image", type="string", length=255, nullable=true)
         */
        private $topic_image;

        /**
         * @var string|null
         *
         * @ORM\Column(name="topic_text1", type="string", length=255, nullable=true)
         */
        private $topic_text1;

        /**
         * @var string|null
         *
         * @ORM\Column(name="topic_text2", type="string", length=255, nullable=true)
         */
        private $topic_text2;

        /**
         * @var \DateTime|null
         *
         * @ORM\Column(name="topic_text3", type="datetimetz", nullable=true)
         */
        private $topic_text3;

        /**
         * @var int|null
         *
         * @ORM\Column(name="sort_no", type="smallint", nullable=true, options={"unsigned":true})
         */
        private $sort_no;

        /**
         * @var boolean
         *
         * @ORM\Column(name="fixed", type="boolean", options={"default":true})
         */
        private $fixed = true;

        /**
         * @var \DateTime
         *
         * @ORM\Column(name="create_date", type="datetimetz")
         */
        private $create_date;

        /**
         * @var \DateTime
         *
         * @ORM\Column(name="update_date", type="datetimetz")
         */
        private $update_date;

        /**
         * @var boolean
         *
         * @ORM\Column(name="visible", type="boolean", options={"default":true})
         */
        private $visible;

        /**
         * @var \Eccube\Entity\Member
         *
         * @ORM\ManyToOne(targetEntity="Eccube\Entity\Member")
         * @ORM\JoinColumns({
         *   @ORM\JoinColumn(name="creator_id", referencedColumnName="id")
         * })
         */
        private $Creator;

        /**
         * Get id.
         *
         * @return int
         */
        public function getId()
        {
            return $this->id;
        }

        /**
         * Set btn_name.
         *
         * @param string|null $btn_name
         *
         * @return Ibn4203Topic
         */
        public function setBtnName($btn_name = null)
        {
            $this->btn_name = $btn_name;

            return $this;
        }

        /**
         * Get btn_name.
         *
         * @return string|null
         */
        public function getBtnName()
        {
            return $this->btn_name;
        }

        /**
         * Set url.
         *
         * @param string|null $url
         *
         * @return Ibn4203Topic
         */
        public function setUrl($url = null)
        {
            $this->url = $url;

            return $this;
        }

        /**
         * Get url.
         *
         * @return string|null
         */
        public function getUrl()
        {
            return $this->url;
        }

        /**
         * Set linkMethod.
         *
         * @param boolean $linkMethod
         *
         * @return Ibn4203Topic
         */
        public function setLinkMethod($linkMethod)
        {
            $this->link_method = $linkMethod;

            return $this;
        }

        /**
         * Get linkMethod.
         *
         * @return boolean
         */
        public function isLinkMethod()
        {
            return $this->link_method;
        }

        /**
         * Set topicImage.
         *
         * @param string|null $topicImage
         *
         * @return TopImage
         */
        public function setTopicImage($topicImage = null)
        {
            $this->topic_image = $topicImage;

            return $this;
        }

        /**
         * Get topicImage.
         *
         * @return string|null
         */
        public function getTopicImage()
        {
            return $this->topic_image;
        }

        /**
         * Set topicText1.
         *
         * @param string|null $topicText1
         *
         * @return topicText1
         */
        public function setTopicText1($topicText1 = null)
        {
            $this->topic_text1 = $topicText1;

            return $this;
        }

        /**
         * Get topicText1.
         *
         * @return string|null
         */
        public function getTopicText1()
        {
            return $this->topic_text1;
        }

        /**
         * Set topicText2.
         *
         * @param string|null $topicText2
         *
         * @return topicText2
         */
        public function setTopicText2($topicText2 = null)
        {
            $this->topic_text2 = $topicText2;

            return $this;
        }

        /**
         * Get topicText2.
         *
         * @return string|null
         */
        public function getTopicText2()
        {
            return $this->topic_text2;
        }

        /**
         * Set topicText3.
         *
         * @param \DateTime|null $publishDate
         *
         * @return topicText3
         */
        public function setTopicText3($topicText3 = null)
        {
            $this->topic_text3 = $topicText3;

            return $this;
        }

        /**
         * Get topicText3.
         *
         * @return \DateTime|null
         */
        public function getTopicText3()
        {
            return $this->topic_text3;
        }

        /**
         * Set sortNo.
         *
         * @param int|null $sortNo
         *
         * @return Payment
         */
        public function setSortNo($sortNo = null)
        {
            $this->sort_no = $sortNo;

            return $this;
        }

        /**
         * Get sortNo.
         *
         * @return int|null
         */
        public function getSortNo()
        {
            return $this->sort_no;
        }

        /**
         * Set fixed.
         *
         * @param boolean $fixed
         *
         * @return Payment
         */
        public function setFixed($fixed)
        {
            $this->fixed = $fixed;

            return $this;
        }

        /**
         * Get fixed.
         *
         * @return boolean
         */
        public function isFixed()
        {
            return $this->fixed;
        }

        /**
         * Set createDate.
         *
         * @param \DateTime $createDate
         *
         * @return Ibn4203Topic
         */
        public function setCreateDate($createDate)
        {
            $this->create_date = $createDate;

            return $this;
        }

        /**
         * Get createDate.
         *
         * @return \DateTime
         */
        public function getCreateDate()
        {
            return $this->create_date;
        }

        /**
         * Set updateDate.
         *
         * @param \DateTime $updateDate
         *
         * @return Ibn4203Topic
         */
        public function setUpdateDate($updateDate)
        {
            $this->update_date = $updateDate;

            return $this;
        }

        /**
         * Get updateDate.
         *
         * @return \DateTime
         */
        public function getUpdateDate()
        {
            return $this->update_date;
        }

        /**
         * @return integer
         */
        public function isVisible()
        {
            return $this->visible;
        }

        /**
         * @param boolean $visible
         *
         * @return Ibn4203Topic
         */
        public function setVisible($visible)
        {
            $this->visible = $visible;

            return $this;
        }

        /**
         * Set creator.
         *
         * @param \Eccube\Entity\Member|null $creator
         *
         * @return Ibn4203Topic
         */
        public function setCreator(\Eccube\Entity\Member $creator = null)
        {
            $this->Creator = $creator;

            return $this;
        }

        /**
         * Get creator.
         *
         * @return \Eccube\Entity\Member|null
         */
        public function getCreator()
        {
            return $this->Creator;
        }
    }
}
