<?php

/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\ForIbn4203\Entity;

use Doctrine\ORM\Mapping as ORM;
use Eccube\Entity\AbstractEntity;

/**
 * ToppageSlide
 *
 * @ORM\Table(name="plg_toppage_slide")
 * @ORM\InheritanceType("SINGLE_TABLE")
 * @ORM\DiscriminatorColumn(name="discriminator_type", type="string", length=255)
 * @ORM\HasLifecycleCallbacks()
 * @ORM\Entity(repositoryClass="Plugin\ForIbn4203\Repository\ToppageSlideRepository")
 */
class ToppageSlide extends AbstractEntity
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer", options={"unsigned":true})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $id;

    /**
     * @var string|null
     *
     * @ORM\Column(name="url", type="string", length=4000, nullable=true)
     */
    private $url;

    /**
     * @var boolean
     *
     * @ORM\Column(name="link_method", type="boolean", options={"default":false})
     */
    private $link_method = false;

	/**
	* @var string
	*
	* @ORM\Column(name="image01", type="text", nullable=true)
	*/
	private $image01;

	/**
	* @var string
	*
	* @ORM\Column(name="image02", type="text", nullable=true)
	*/
	private $image02;

	/**
	* @var string
	*
	* @ORM\Column(name="title01", type="text", nullable=true)
	*/
	private $title01;

	/**
	* @var string
	*
	* @ORM\Column(name="title02", type="text", nullable=true)
	*/
	private $title02;

    /**
     * @var boolean
     *
     * @ORM\Column(name="text_check", type="boolean", options={"default":false})
     */
    private $text_check = false;

    /**
     * @var int|null
     *
     * @ORM\Column(name="sort_no", type="smallint", nullable=true, options={"unsigned":true})
     */
    private $sort_no;

    /**
     * @var boolean
     *
     * @ORM\Column(name="fixed", type="boolean", options={"default":true})
     */
    private $fixed = true;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="create_date", type="datetimetz")
     */
    private $create_date;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="update_date", type="datetimetz")
     */
    private $update_date;

    /**
     * @var boolean
     *
     * @ORM\Column(name="visible", type="boolean", options={"default":true})
     */
    private $visible;

    /**
     * @var \Eccube\Entity\Member
     *
     * @ORM\ManyToOne(targetEntity="Eccube\Entity\Member")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="creator_id", referencedColumnName="id")
     * })
     */
    private $Creator;

    /**
     * Get id.
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set url.
     *
     * @param string|null $url
     *
     * @return ToppageSlide
     */
    public function setUrl($url = null)
    {
        $this->url = $url;

        return $this;
    }

    /**
     * Get url.
     *
     * @return string|null
     */
    public function getUrl()
    {
        return $this->url;
    }

    /**
     * Set linkMethod.
     *
     * @param boolean $linkMethod
     *
     * @return ToppageSlide
     */
    public function setLinkMethod($linkMethod)
    {
        $this->link_method = $linkMethod;

        return $this;
    }

    /**
     * Get linkMethod.
     *
     * @return boolean
     */
    public function isLinkMethod()
    {
        return $this->link_method;
    }

	/**
	* Set image01.
	*
	* @param string $image01
	*
	* @return Ibn4203Eyecatch
	*/
	public function setImage01($image01)
	{
		$this->image01 = $image01;

		return $this;
	}

	/**
	* Get image01.
	*
	* @return string
	*/
	public function getImage01()
	{
		return $this->image01;
	}

	/**
	* Set image02.
	*
	* @param string $image02
	*
	* @return Ibn4203Eyecatch
	*/
	public function setImage02($image02)
	{
		$this->image02 = $image02;

		return $this;
	}

	/**
	* Get image02.
	*
	* @return string
	*/
	public function getImage02()
	{
		return $this->image02;
	}

	/**
	* Set title01.
	*
	* @param string $title01
	*
	* @return Ibn4203Eyecatch
	*/
	public function setTitle01($title01)
	{
		$this->title01 = $title01;

		return $this;
	}

	/**
	* Get title01.
	*
	* @return string
	*/
	public function getTitle01()
	{
		return $this->title01;
	}

	/**
	* Set title02.
	*
	* @param string $title02
	*
	* @return Ibn4203Eyecatch
	*/
	public function setTitle02($title02)
	{
		$this->title02 = $title02;

		return $this;
	}

	/**
	* Get title02.
	*
	* @return string
	*/
	public function getTitle02()
	{
		return $this->title02;
	}

    /**
     * Set textCheck.
     *
     * @param boolean $textCheck
     *
     * @return ToppageSlide
     */
    public function setTextCheck($textCheck)
    {
        $this->text_check = $textCheck;

        return $this;
    }

    /**
     * Get textCheck.
     *
     * @return boolean
     */
    public function isTextCheck()
    {
        return $this->text_check;
    }

    /**
     * Set sortNo.
     *
     * @param int|null $sortNo
     *
     * @return Payment
     */
    public function setSortNo($sortNo = null)
    {
        $this->sort_no = $sortNo;

        return $this;
    }

    /**
     * Get sortNo.
     *
     * @return int|null
     */
    public function getSortNo()
    {
        return $this->sort_no;
    }

    /**
     * Set fixed.
     *
     * @param boolean $fixed
     *
     * @return Payment
     */
    public function setFixed($fixed)
    {
        $this->fixed = $fixed;

        return $this;
    }

    /**
     * Get fixed.
     *
     * @return boolean
     */
    public function isFixed()
    {
        return $this->fixed;
    }

    /**
     * Set createDate.
     *
     * @param \DateTime $createDate
     *
     * @return ToppageSlide
     */
    public function setCreateDate($createDate)
    {
        $this->create_date = $createDate;

        return $this;
    }

    /**
     * Get createDate.
     *
     * @return \DateTime
     */
    public function getCreateDate()
    {
        return $this->create_date;
    }

    /**
     * Set updateDate.
     *
     * @param \DateTime $updateDate
     *
     * @return ToppageSlide
     */
    public function setUpdateDate($updateDate)
    {
        $this->update_date = $updateDate;

        return $this;
    }

    /**
     * Get updateDate.
     *
     * @return \DateTime
     */
    public function getUpdateDate()
    {
        return $this->update_date;
    }

    /**
     * @return integer
     */
    public function isVisible()
    {
        return $this->visible;
    }

    /**
     * @param boolean $visible
     *
     * @return ToppageSlide
     */
    public function setVisible($visible)
    {
        $this->visible = $visible;

        return $this;
    }

    /**
     * Set creator.
     *
     * @param \Eccube\Entity\Member|null $creator
     *
     * @return ToppageSlide
     */
    public function setCreator(\Eccube\Entity\Member $creator = null)
    {
        $this->Creator = $creator;

        return $this;
    }

    /**
     * Get creator.
     *
     * @return \Eccube\Entity\Member|null
     */
    public function getCreator()
    {
        return $this->Creator;
    }
}
