<?php

/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Plugin\ForIbn4203;

use Eccube\Application;
use Eccube\Entity\Block;
use Eccube\Entity\BlockPosition;
use Eccube\Entity\Layout;
use Eccube\Entity\Master\DeviceType;
use Eccube\Plugin\AbstractPluginManager;
use Eccube\Repository\BlockPositionRepository;
use Eccube\Repository\BlockRepository;
use Eccube\Repository\LayoutRepository;
use Eccube\Repository\Master\DeviceTypeRepository;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Filesystem\Filesystem;

use Doctrine\ORM\EntityManagerInterface;

use Eccube\Common\EccubeConfig;
use Eccube\Util\EntityUtil;
use Plugin\ForIbn4203\Entity\ForIbn4203Config;
use Plugin\ForIbn4203\Repository\ForIbn4203ConfigRepository;

/**
 * Class PluginManager.
 */
class PluginManager extends AbstractPluginManager
{
    /**
     * PluginManager constructor.
     */
    public function __construct()
    {
    }

    /**
     * @param null $meta
     * @param Application|null $app
     * @param ContainerInterface $container
     *
     * @throws \Exception
     */
    public function install(array $meta, ContainerInterface $container)
    {
        $fs = new Filesystem();

        $dir = sprintf('%s/app/template/%s/Block',
            $container->getParameter('kernel.project_dir'),
            $container->getParameter('eccube.theme'));

        if(!file_exists($dir)) {
            $fs->mkdir($dir, 0777);
        }

        try {

            $plgDir = sprintf('%s/app/Plugin/ForIbn4203/Copy/new_product_auto.twig',
                $container->getParameter('kernel.project_dir'));

            $fs->copy($plgDir, $dir. '/new_product_auto.twig', true);

        } catch (\Exception $e) {
            return false;
        }
	}

    /**
     * @param null $meta
     * @param Application|null $app
     * @param ContainerInterface $container
     *
     * @throws \Exception
     */
    public function uninstall(array $meta, ContainerInterface $container)
    {
        $em = $container->get('doctrine.orm.entity_manager');

        $Config = $em->find(ForIbn4203Config::class, 1);
        $Block = $Config->getBlockId();

        $Config->setBlockId(null);
        $em->flush($Config);

        $em->remove($Block);
        $em->flush($Block);

        $fs = new Filesystem();

        $dir = sprintf('%s/app/template/%s/Block',
            $container->getParameter('kernel.project_dir'),
            $container->getParameter('eccube.theme'));

        try {

            $fs->remove($dir.'/new_product_auto.twig');

        } catch (\Exception $e) {
            return false;
        }
    }

    /**
     * @param null|array $meta
     * @param ContainerInterface $container
     *
     * @throws \Exception
     */
    public function enable(array $meta = null, ContainerInterface $container)
    {
        // twigの置き換え
		$this->copyTwigFile($container);
		
		// プラグイン設定を追加
		$em = $container->get('doctrine.orm.entity_manager');
        $Config = $this->createConfig($em);

        // ブロックを追加
        if (!$Config->getBlockId()) {
            $Block = $this->createBlock($em);

            $Config->setBlockId($Block);
            $em->flush($Config);
        }
		
    }

    /**
     * @param array|null $meta
     * @param ContainerInterface $container
     */
    public function disable(array $meta = null, ContainerInterface $container)
    {
		// twigを元に戻す
		$this->removeTwigFile($container);
    }

    /**
     * @param array|null $meta
     * @param ContainerInterface $container
     */
    public function update(array $meta = null, ContainerInterface $container)
    {
    }

    // twigの置き換え　元のファイル→******_BackUp.twig
	private function copyTwigFile(ContainerInterface $container)
    {
		$templateDir = $container->getParameter('eccube_theme_front_dir');		
		$fs = new Filesystem();
		// top_slider.twig
		$fs->copy($templateDir.'/Block/top_slider.twig', $templateDir.'/Block/top_slider_Backup.twig');
		$fs->remove($templateDir.'/Block/top_slider.twig');
		$plgTwig= sprintf('%s/app/Plugin/ForIbn4203/Copy/top_slider.twig', $container->getParameter('kernel.project_dir'));
		$fs->copy($plgTwig, $templateDir.'/Block/top_slider.twig', true);
		// eyecatch.twig
		$fs->copy($templateDir.'/Block/eyecatch.twig', $templateDir.'/Block/eyecatch_Backup.twig');
		$fs->remove($templateDir.'/Block/eyecatch.twig');
		$plgTwig= sprintf('%s/app/Plugin/ForIbn4203/Copy/eyecatch.twig', $container->getParameter('kernel.project_dir'));
		$fs->copy($plgTwig, $templateDir.'/Block/eyecatch.twig', true);
		// topic.twig
		$fs->copy($templateDir.'/Block/topic.twig', $templateDir.'/Block/topic_Backup.twig');
		$fs->remove($templateDir.'/Block/topic.twig');
		$plgTwig= sprintf('%s/app/Plugin/ForIbn4203/Copy/topic.twig', $container->getParameter('kernel.project_dir'));
		$fs->copy($plgTwig, $templateDir.'/Block/topic.twig', true);
		// list_banner.twig
		$fs->copy($templateDir.'/Product/list_banner.twig', $templateDir.'/Product/list_banner_Backup.twig');
		$fs->remove($templateDir.'/Product/list_banner.twig');
		$plgTwig= sprintf('%s/app/Plugin/ForIbn4203/Copy/list_banner.twig', $container->getParameter('kernel.project_dir'));
		$fs->copy($plgTwig, $templateDir.'/Product/list_banner.twig', true);
    }

    // twigを元に戻す
    private function removeTwigFile(ContainerInterface $container)
    {
		$templateDir = $container->getParameter('eccube_theme_front_dir');		
		$fs = new Filesystem();
		// top_slider.twig
		$fs->remove($templateDir.'/Block/top_slider.twig');
		$fs->copy($templateDir.'/Block/top_slider_Backup.twig', $templateDir.'/Block/top_slider.twig');
		$fs->remove($templateDir.'/Block/top_slider_Backup.twig');
		// eyecatch.twig
		$fs->remove($templateDir.'/Block/eyecatch.twig');
		$fs->copy($templateDir.'/Block/eyecatch_Backup.twig', $templateDir.'/Block/eyecatch.twig');
		$fs->remove($templateDir.'/Block/eyecatch_Backup.twig');
		// topic.twig
		$fs->remove($templateDir.'/Block/topic.twig');
		$fs->copy($templateDir.'/Block/topic_Backup.twig', $templateDir.'/Block/topic.twig');
		$fs->remove($templateDir.'/Block/topic_Backup.twig');
		// list_banner.twig
		$fs->remove($templateDir.'/Product/list_banner.twig');
		$fs->copy($templateDir.'/Product/list_banner_Backup.twig', $templateDir.'/Product/list_banner.twig');
		$fs->remove($templateDir.'/Product/list_banner_Backup.twig');
    }
	
    protected function createConfig(EntityManagerInterface $em)
    {
        $Config = $em->find(ForIbn4203Config::class, 1);
        if ($Config) {
            return $Config;
        }
        $Config = new ForIbn4203Config();
        $Config->setNewitemSort(0);
        $Config->setNewitemCount(10);

        $Config->setEyecatchTitle('－ New Arrival Products －');
        $Config->setTopicTitle('－ TOPICS －');
        $Config->setNewItemTitle('－ NEW ITEM －');

        $em->persist($Config);
        $em->flush($Config);

        return $Config;
    }

    protected function createBlock(EntityManagerInterface $em)
    {
        $DeviceType = $em->find(DeviceType::class, DeviceType::DEVICE_TYPE_PC);

        $result = $em->createQueryBuilder('ct')
            ->select('COALESCE(MAX(ct.id), 0) AS id')
            ->from(Block::class, 'ct')
            ->getQuery()
            ->getSingleResult();

        $result['id']++;

        $Block = new Block();
        $Block
            ->setId($result['id'])
            ->setName('新着商品自動表示')
            ->setDeviceType($DeviceType)
            ->setFileName('new_product_auto')
            ->setUseController(1)
            ->setDeletable(0);
        $em->persist($Block);
        $em->flush($Block);

        return $Block;
    }
}
